Lorenz.Population: Defines the population used in the genetic algorithm
Description
Lorenz.Population creates the initial population of the genetic algorithm used to solve the Lorenz regression.
Usage
Lorenz.Population(object)
Value
A matrix of dimension object@popSize times the number of explanatory variables minus one, gathering the initial population.
Arguments
- object
An object of class "ga", resulting from a call to function ga.
Details
Note that this population produces an initial solution ensuring a unit norm.