Lorenz.ga.call encapsulates the call to ga for a local management of seed setting
Lorenz.ga.call(
ties.method,
y,
x,
pi,
V,
popSize,
maxiter,
run,
parallel.GA,
suggestions,
seed = NULL
)The fitted genetic algorithm
Either "mean" or "random".
vector of responses.
matrix of covariates.
sample weights (normalized).
vector of uniformly distributed rvs.
passed to ga.
passed to ga.
passed to ga.
passed to ga.
passed to ga.
An optional integer for setting the seed for random number generation. Default is NULL.