Provides bootstrap confidence intervals for the explained Gini coefficient, Lorenz-R2 and theta vector for an object of class "LR_boot".
# S3 method for LR_boot
confint(
object,
parm = c("Gini", "LR2", "theta"),
level = 0.95,
type = c("norm", "basic", "perc"),
bias.corr = TRUE,
...
)The desired confidence interval.
If parm="Gini" or parm="LR2", the output is a vector.
If parm="theta", it is a matrix where each row corresponds to a different coefficient.
An object of class "LR_boot". The current implementation requires bootstrap to construct confidence intervals. Hence, it is not sufficient that object inherits from "LR".
A logical value determining whether the confidence interval is computed for the explained Gini coefficient, for the Lorenz-\(R^2\) or for the vector of coefficients of the single-index model. Possible values are "Gini" (default, for the explained Gini),"LR2" (for the Lorenz-\(R^2\)) and "theta" (for the index coefficients).
A numeric giving the level of the confidence interval. Default value is 0.95.
A character string specifying the bootstrap method. Possible values are "norm", "basic" and "perc". For more information, see the argument type of the function boot.ci from the boot library.
A logical determining whether bias correction should be performed. Only used if type="norm". Default is TRUE.
Additional arguments.
Lorenz.boot, boot.ci
## For examples see example(Lorenz.boot)
Run the code above in your browser using DataLab