print.LR: Printing method for the Lorenz regression
Description
Prints the arguments, explained Gini coefficient and estimated coefficients of an object of class "LR".
Usage
# S3 method for LR
print(x, digits = max(3L, getOption("digits") - 3L), ...)Value
No return value, called for printing an object of class "LR" to the console.
Arguments
- x
An object of class "LR".
- digits
The number of significant digits to be passed.
- ...
Additional arguments.
Examples
Run this code## For examples see example(Lorenz.Reg)
Run the code above in your browser using DataLab